/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWRUNTIME_PROFILE_NAMESPACE_HPP__
#define __FWRUNTIME_PROFILE_NAMESPACE_HPP__


namespace fwRuntime
{
/**
 * @brief       The namespace fwRuntime::profile contains classes to manage bundle declares in profile.xml file (activate/start/stop).
 * @namespace   fwRuntime::profile
 *
 * @date        2009-2010.
 *
 */
namespace profile
{

}
}
#endif /* __FWRUNTIME_PROFILE_NAMESPACE_HPP__ */
